===================
urwid-stackedwidget
===================

``urwid-stackedwidget`` is a widget container that presents one child widget at a time. It provides the following features:

- To have multiple widgets in memory
- To show only one of them at a time
- To switch to a different widget



Installation
============

::

    pip install urwid-stackedwidget
